%% Optimale Regelung
%% Entwurf einer optimalen Zustandsregelung
%% fr ein Labormodell (Inverses Pendel)
close all
clear all
clc

%Definieren der Konstanten
m=1*10^3;
M=10*10^3;
l=1;
g=9.80655;
beta1=M+m;
beta2=1/(M+0.5*m);
a23=(-0.5*g*m)/beta2;
a43=(g*beta1)/(2*l*beta2);
b2=1/beta2;
b4=(-1)/(2*l*beta2);

%Zustandsbeschreibung in Matrizenschreibweise (1-Gren-System)
%x1 := Position des Wagens
%x2 := Geschwindigkeit des Wagens
%x3 := Winkel des Pendels
%x4 := Geschwindigkeit des Pendels
%u := Beschleunigung  (aktive Beeinflussung des Pendels)
%Systemmatrix
A=[0,1,0,0;0,0,-5.1484*10^7,0;0,0,0,1;0,0,5.6633*10^8,0];
%Eingangsmatrix
b=[0;10500;0;-5250];
%Ausgangsmatrix
cT=[0,0,1,0];
%Durchgangsmatrix
d=0;

%Steuerbarkeit berprfen
Qs=[b,A*b,A^2*b,A^3*b]%Steuerbarkeitsmatrix
r=rank(Qs);
n=4;
if r==n
    'System ist vollstndig steuerbar und somit stabilisierbar!!!'
end

%Simulieren
sim('invpen_oreg.mdl',120);%Simulation ber zwei Minuten (zum Nachvollziehen)
%sim('invpen_mreg.mdl',120);

%Ausgabe 
hold off
pendelwinkel=plot(t,pwin,'r');
set(pendelwinkel,'LineStyle','-');
set(pendelwinkel,'LineWidth',1.75);
grid on
grid MINOR
title('Inverses Pendel\newline(linearisiertes Modell)\newline(ohne Regelung)','FontSize',14,'FontWeight','Bold');
xlabel('Zeit in [sec] \rightarrow');
ylabel('Winkel in [] \rightarrow');
legend('Winkel des Pendels','location','SouthEast');